@@ -108,11 +108,13 @@ class ServiceNameCatalog:
         ServiceName("acm", "ACM"),
         ServiceName("alexaforbusiness", "AlexaForBusiness"),
         ServiceName("amplify", "Amplify"),
+        ServiceName("amplifybackend", "AmplifyBackend"),
         ServiceName("apigateway", "APIGateway"),
         ServiceName("apigatewaymanagementapi", "ApiGatewayManagementApi"),
         ServiceName("apigatewayv2", "ApiGatewayV2"),
         ServiceName("appconfig", "AppConfig"),
         ServiceName("appflow", "Appflow"),
+        ServiceName("appintegrations", "AppIntegrationsService"),
         ServiceName("application-autoscaling", "ApplicationAutoScaling"),
         ServiceName("application-insights", "ApplicationInsights"),
         ServiceName("appmesh", "AppMesh"),
@@ -154,9 +156,11 @@ class ServiceNameCatalog:
         ServiceName("comprehendmedical", "ComprehendMedical"),
         ServiceName("compute-optimizer", "ComputeOptimizer"),
         ServiceName("config", "ConfigService"),
+        ServiceName("connect-contact-lens", "ConnectContactLens"),
         ServiceName("connect", "Connect"),
         ServiceName("connectparticipant", "ConnectParticipant"),
         ServiceName("cur", "CostandUsageReportService"),
+        ServiceName("customer-profiles", "CustomerProfiles"),
         ServiceName("databrew", "GlueDataBrew"),
         ServiceName("dataexchange", "DataExchange"),
         ServiceName("datapipeline", "DataPipeline"),
@@ -164,6 +168,7 @@ class ServiceNameCatalog:
         ServiceName("dax", "DAX"),
         ServiceName("detective", "Detective"),
         ServiceName("devicefarm", "DeviceFarm"),
+        ServiceName("devops-guru", "DevopsGuru"),
         ServiceName("directconnect", "DirectConnect"),
         ServiceName("discovery", "ApplicationDiscoveryService"),
         ServiceName("dlm", "DLM"),
@@ -175,6 +180,7 @@ class ServiceNameCatalog:
         ServiceName("ebs", "EBS"),
         ServiceName("ec2-instance-connect", "EC2InstanceConnect"),
         ServiceName("ec2", "EC2"),
+        ServiceName("ecr-public", "ECRPublic"),
         ServiceName("ecr", "ECR"),
         ServiceName("ecs", "ECS"),
         ServiceName("efs", "EFS"),
@@ -237,6 +243,7 @@ class ServiceNameCatalog:
         ServiceName("license-manager", "LicenseManager"),
         ServiceName("lightsail", "Lightsail"),
         ServiceName("logs", "CloudWatchLogs"),
+        ServiceName("lookoutvision", "LookoutforVision"),
         ServiceName("machinelearning", "MachineLearning"),
         ServiceName("macie", "Macie"),
         ServiceName("macie2", "Macie2"),
@@ -294,6 +301,7 @@ class ServiceNameCatalog:
         ServiceName("s3control", "S3Control"),
         ServiceName("s3outposts", "S3Outposts"),
         ServiceName("sagemaker-a2i-runtime", "AugmentedAIRuntime"),
+        ServiceName("sagemaker-featurestore-runtime", "SagemakerFeatureStoreRuntime"),
         ServiceName("sagemaker-runtime", "SageMakerRuntime"),
         ServiceName("sagemaker", "SageMaker"),
         ServiceName("savingsplans", "SavingsPlans"),
@@ -303,8 +311,8 @@ class ServiceNameCatalog:
         ServiceName("securityhub", "SecurityHub"),
         ServiceName("serverlessrepo", "ServerlessApplicationRepository"),
         ServiceName("service-quotas", "ServiceQuotas"),
-        ServiceName("servicecatalog", "ServiceCatalog"),
         ServiceName("servicecatalog-appregistry", "AppRegistry"),
+        ServiceName("servicecatalog", "ServiceCatalog"),
         ServiceName("servicediscovery", "ServiceDiscovery"),
         ServiceName("ses", "SES"),
         ServiceName("sesv2", "SESV2"),
